@@ -10,6 +10,9 @@
 #'    specify is higher than the total number of districts for that state,
 #'    a 404 response will be returned.
 #' @return List of members of a particular chamber in a particular Congress.
+#' @references Congress API docs 
+#' <https://projects.propublica.org/api-docs/congress-api/>
+#' @family congress
 #' @examples \dontrun{
 #' cg_memberslist(congress_no = 112, chamber = 'senate', state = "TX")
 #' cg_memberslist(112, 'senate', 'NH')
@@ -20,7 +23,8 @@
   
   url <- sprintf("%s/%s/%s/members.json", cg_base(), congress_no, chamber)
   args <- rc(list(state = state, district = district))
-  res <- rtimes_GET(url, args, FALSE, add_key(check_key(key, "PROPUBLICA_API_KEY")), ...)
+  res <- rtimes_GET(url, args, FALSE, 
+                    list(...), add_key(check_key(key, "PROPUBLICA_API_KEY")))
   df <- tibble::as_data_frame(to_df(res$results[[1]]$members))
   list(status = res$status, copyright = res$copyright,
        meta = do_data_frame(res), data = df)
